# -*- coding: utf-8 -*-
import irc3
import os
import re
import requests

from irc3 import event, IrcBot

from . import Plugin
from ..utils import fmt, date_from_iso

YOUTUBE_URL = 'https://www.googleapis.com/youtube/v3'
YOUTUBE_API = '{}/videos?part=snippet,statistics,contentDetails' \
    .format(YOUTUBE_URL)
YOUTUBE_SEARCH = '{}/search?part=id,snippet'.format(YOUTUBE_URL)


@irc3.plugin
class Media(Plugin):
    requires = [
        'irc3.plugins.command',
    ]

    def __init__(self, bot: IrcBot):
        super().__init__(bot)
        self.GOOGLE_API_KEY = os.environ['GOOGLE_API_KEY']

    @event(r'(?i)^:.* PRIVMSG (?P<target>.*) :.*(?:youtube.*?(?:v=|/v/)'
           r'|youtu\.be/)(?P<video_id>[-_a-zA-Z0-9]+).*')
    def youtube(self, target: str, video_id: str):
        req = requests.get(YOUTUBE_API, params={
            'key': self.GOOGLE_API_KEY,
            'id': video_id})
        data = req.json()

        if not data['items']:
            return

        item = data['items'][0]
        stats = item['statistics']
        date = date_from_iso(item['snippet']['publishedAt'])
        length = item['contentDetails']['duration']
        length = re.findall('(\d+[DHMS])', length)
        likes = int(stats.get('likeCount', 0))
        dislikes = int(stats.get('dislikeCount', 0))

        try:
            score = 100 * float(likes) / (likes + dislikes)
        except ZeroDivisionError:
            score = 0

        res = fmt('{title} - length {length} -{color}{green} {likes:,}{reset} '
                  '/{color}{maroon} {dislikes:,}{reset} ({score:,.1f}%) - '
                  '{views:,} views - {channel} on {date}',
                  title=item['snippet']['localized']['title'],
                  channel=item['snippet']['channelTitle'],
                  length=' '.join([l.lower() for l in length]),
                  date=date.strftime('%Y.%m.%d'),
                  views=int(stats.get('viewCount', 0)),
                  likes=likes,
                  dislikes=dislikes,
                  score=score)
        self.bot.privmsg(target, res)
